@@ -6,7 +6,7 @@
 #              values) and simple values (string/macro/number).
 # CREATED    : 1998/03/12, Greg Ward
 # MODIFIED   : 
-# VERSION    : $Id$
+# VERSION    : $Id: Value.pm 8423 2010-02-13 20:40:27Z ambs $
 # COPYRIGHT  : Copyright (c) 1997-2000 by Gregory P. Ward.  All rights
 #              reserved.
 # 
@@ -18,12 +18,9 @@
 package Text::BibTeX::Value;
 
 use strict;
-use Scalar::Util 'blessed';
+use UNIVERSAL 'isa';
 use Carp;
 
-use vars qw'$VERSION';
-$VERSION = 0.76_02;
-
 =head1 NAME
 
 Text::BibTeX::Value - interfaces to BibTeX values and simple values
@@ -32,7 +29,7 @@ Text::BibTeX::Value - interfaces to BibTeX values and simple values
 
    use Text::BibTeX;
 
-   $entry = Text::BibTeX::Entry->new;
+   $entry = new Text::BibTeX::Entry;
 
    # set the 'preserve_values' flag to 1 for this parse
    $entry->parse ($filename, $filehandle, 1);
@@ -80,7 +77,7 @@ C<title> field is a single string, and the C<journal> and C<year> fields
 are, respectively, a single macro and a single number.  If you parse
 this entry in the usual way:
 
-   $entry = Text::BibTeX::Entry->new($entry_text);
+   $entry = new Text::BibTeX::Entry $entry_text;
 
 then the C<get> method on C<$entry> would return simple strings.
 Assuming that the C<and> macro is defined as C<" and ">, then
@@ -96,14 +93,14 @@ There are two ways to make this request: per-file and per-entry.  For a
 per-file request, use the C<preserve_values> method on your C<File>
 object:
 
-   $bibfile = Text::BibTeX::File->new($filename);
+   $bibfile = new Text::BibTeX::File $filename;
    $bibfile->preserve_values (1);
 
-   $entry = Text::BibTeX::Entry->new($bibfile);
+   $entry = new Text::BibTeX::Entry $bibfile;
    $entry->get ($field);        # returns a Value object
 
    $bibfile->preserve_values (0);
-   $entry = Text::BibTeX::Entry->new($bibfile);
+   $entry = new Text::BibTeX::Entry $bibfile;
    $entry->get ($field);        # returns a string
 
 If you're not using a C<File> object, or want to control things at a
@@ -111,7 +108,7 @@ finer scale, then you have to pass in the C<preserve_values> flag when
 invoking C<read>, C<parse>, or C<parse_s> on your C<Entry> objects:
 
    # no File object, parsing from a string
-   $entry = Text::BibTeX::Entry->new;
+   $entry = new Text::BibTeX::Entry;
    $entry->parse_s ($entry_text, 0);  # preserve_values=0 (default)
    $entry->get ($field);        # returns a string
 
@@ -183,8 +180,8 @@ two-element list containing the type and text of the simple value.  For
 example, one way to recreate the C<author> field of the example entry in
 L<"DESCRIPTION"> would be:
 
-   $and_macro = Text::BibTeX::SimpleValue->new (BTAST_MACRO, 'and');
-   $value = Text::BibTeX::Value->new 
+   $and_macro = new Text::BibTeX::SimpleValue (BTAST_MACRO, 'and');
+   $value = new Text::BibTeX::Value 
       ([BTAST_STRING, 'Homer Simpson'],
        $and_macro,
        [BTAST_STRING, 'Ned Flanders']);
@@ -202,11 +199,11 @@ sub new
    my $self = bless [], $class;
    while (my $sval = shift)
    {
-      $sval = Text::BibTeX::SimpleValue->new(@$sval)
+      $sval = new Text::BibTeX::SimpleValue @$sval
          if ref $sval eq 'ARRAY' && @$sval == 2;
       croak "simple value is neither a two-element array ref " .
             "nor a Text::BibTeX::SimpleValue object"
-         unless blessed($sval) && $sval->isa('Text::BibTeX::SimpleValue');
+         unless isa ($sval, 'Text::BibTeX::SimpleValue');
       push (@$self, $sval);
    }
 
@@ -244,10 +241,6 @@ use strict;
 use Carp;
 use Text::BibTeX qw(:nodetypes);
 
-use vars qw($VERSION);
-$VERSION = '0.76_02';
-
-
 =head2 Text::BibTeX::SimpleValue methods
 
 =over
